JasonWoof Got questions, comments, patches, etc.? Contact Jason Woofenden
stop showing tiny agreement to contractor when he switches users
[contractor-progress.git] / index.php
index ab4ff12..03e3077 100644 (file)
--- a/index.php
+++ b/index.php
@@ -115,11 +115,18 @@ function totals_summary($arr) {
 
 function _index_main() {
        $client_id = logged_in();
+       $ever_was_contractor = ever_was_contractor();
 
-       # make sure they've filled out the tiny user agreement
-       $tiny_agreement = db_get_value('people', 'tiny_agreement', 'where id=%i', $client_id);
-       if($tiny_agreement < 30 || $tiny_agreement > 999) {
-               return './tiny_agreement';
+       # make sure the client (not the contractor) has filled out the tiny agreement
+       if(!$ever_was_contractor) {
+               $tiny_agreement = db_get_value('people', 'tiny_agreement', 'where id=%i', $client_id);
+               if($tiny_agreement < 30 || $tiny_agreement > 999) {
+                       return './tiny_agreement';
+               }
+       }
+
+       if($ever_was_contractor) {
+               tem_show('su_link');
        }
 
        if(logged_in_as_contractor()) {
@@ -139,10 +146,10 @@ function _index_main() {
                task_summary('finished_paid', 'where state=%i && paid = 1 order by finished_at desc limit 20', TASK_FINISHED);
        } else {
                tem_show('not_contractor_links');
-               if(db_count('tasks', 'where client_id=%i && (state=%i || state=%i || state=%i || state=%i)', $client_id, TASK_DRAFT, TASK_NEEDS_CLARIFICATION, TASK_NEEDS_GO_AHEAD, TASK_NEEDS_TESTING)) {
+               if(db_count('tasks', 'where client_id=%i && (state=%i || state=%i || state=%i || state=%i || state=%i)', $client_id, TASK_DRAFT, TASK_NEEDS_CLARIFICATION, TASK_ON_HOLD, TASK_NEEDS_GO_AHEAD, TASK_NEEDS_TESTING)) {
                        tem_show('needs_attention_header');
                        task_summary('needs_approval', 'where client_id=%i && (state=%i || state=%i) order by id', $client_id, TASK_NEEDS_GO_AHEAD, TASK_NEEDS_TESTING);
-                       task_summary('needs_fixing', 'where client_id=%i && (state=%i || state=%i) order by id', $client_id, TASK_DRAFT, TASK_NEEDS_CLARIFICATION);
+                       task_summary('needs_fixing', 'where client_id=%i && (state=%i || state=%i || state=%i) order by id', $client_id, TASK_ON_HOLD, TASK_DRAFT, TASK_NEEDS_CLARIFICATION);
                }
                task_summary('queue', 'where client_id=%i && state=%i order by ord desc', $client_id, TASK_QUEUED);
                task_summary('jason', 'where client_id=%i && (state=%i || state=%i) order by id desc', $client_id, TASK_NEEDS_QUOTE, TASK_BUG);